/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.war.impl;

import org.ow2.util.ee.metadata.war.api.IWarClassMetadata;
import org.ow2.util.ee.metadata.war.api.IWarDeployableMetadata;
import org.ow2.util.ee.metadata.war.api.IWarFieldMetadata;
import org.ow2.util.ee.metadata.war.api.IWarMethodMetadata;
import org.ow2.util.ee.metadata.ws.impl.WebservicesCommonClassMetadata;
import org.ow2.util.scan.api.metadata.structures.JClass;


/**
 * This class represents the annotation metadata of a Bean.<br>
 * From this class, we can access to all methods of a bean with its associated information.
 * @author Florent Benoit
 */
public class WarClassMetadata extends WebservicesCommonClassMetadata<IWarClassMetadata, IWarMethodMetadata, IWarFieldMetadata> implements
        IWarClassMetadata {

    /**
     * Logger.
     */
    // private static final Log LOGGER = LogFactory.getLog(WarClassMetadata.class);

    /**
     * Parent meta data.
     */
    private IWarDeployableMetadata warDeployableMetadata = null;

    /**
     * Constructor.
     * @param jClass jClass.
     * @param warDeployableMetadata parent metadata object.
     */
    public WarClassMetadata(final JClass jClass, final WarDeployableMetadata warDeployableMetadata) {
        super();
        setJClass(jClass);
        this.warDeployableMetadata = warDeployableMetadata;
    }

    /**
     * @return the archive metadata
     */
    public IWarDeployableMetadata getWarDeployableMetadata() {
        return this.warDeployableMetadata;
    }

}
