/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.war.impl;

import org.ow2.util.ee.deploy.api.deployable.WARDeployable;
import org.ow2.util.ee.metadata.ws.api.xml.struct.IWebservices;
import org.ow2.util.ee.metadata.common.impl.AbsEnvironmentRefAccessor;
import org.ow2.util.ee.metadata.war.api.IWarClassMetadata;
import org.ow2.util.ee.metadata.war.api.IWarDeployableMetadata;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

/**
 * This class represents the annotation metadata of all classes of a War
 * file. From this class, we can get metadata of all classes.
 * @author Florent Benoit
 */
public class WarDeployableMetadata extends AbsEnvironmentRefAccessor implements IWarDeployableMetadata {

    /**
     * List of class annotations metadata.
     */
    private Map<String, IWarClassMetadata> warClassMetadataMap = null;

    /**
     * The war deployable.
     */
    private WARDeployable warDeployable;

    /**
     * Link to the Webservices.
     */
    private IWebservices webservices = null;

    /**
     * Constructor.
     * @param warDeployable the war deployable
     */
    public WarDeployableMetadata(final WARDeployable warDeployable) {
        this.warDeployable = warDeployable;
        warClassMetadataMap = new HashMap<String, IWarClassMetadata>();
    }

    /**
     * Add annotation metadata for a given class.
     * @param warClassMetadata metadata of a class.
     */
    public void addWarClassMetadata(final IWarClassMetadata warClassMetadata) {
        String key = warClassMetadata.getJClass().getName();
        // already exists ?
        if (warClassMetadataMap.containsKey(key)) {
            throw new IllegalStateException("addWarClassMetadata : key already exists");
        }
        warClassMetadataMap.put(key, warClassMetadata);
    }


    /**
     * Get class annotation metadata.
     * @param className key of the map of annotations bean.
     * @return Bean annotation metadata of a given name.
     */
    public IWarClassMetadata getWarClassMetadata(final String className) {
        return warClassMetadataMap.get(className);
    }

    /**
     * Get collections of bean annotation metadata.
     * @return collections of bean annotation metadata.
     */
    public Collection<IWarClassMetadata> getWarClassMetadataCollection() {
        return warClassMetadataMap.values();
    }

    /**
     * @return the webservices 1.2 deployment descriptor object.
     */
    public IWebservices getWebservices12() {
        return webservices;
    }

    /**
     * Sets the webservices 1.2 deployment descriptor object.
     *
     * @param webservices12 the webservices 1.2 deployment descriptor object.
     */
    public void setWebservices12(IWebservices webservices12) {
        this.webservices = webservices12;
    }

    /**
     * @return the web archive
     */
    public WARDeployable getDeployable() {
        return warDeployable;
    }

}
