/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.war.impl.specific;

import org.ow2.util.ee.metadata.common.impl.specific.SpecificCommonClassMetadata;
import org.ow2.util.ee.metadata.war.api.IWarClassMetadata;
import org.ow2.util.ee.metadata.war.api.IWarDeployableMetadata;
import org.ow2.util.ee.metadata.war.api.IWarFieldMetadata;
import org.ow2.util.ee.metadata.war.api.IWarMethodMetadata;
import org.ow2.util.ee.metadata.ws.api.struct.IWebServiceMarker;
import org.ow2.util.scan.api.metadata.specific.ISpecificClassMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificFieldMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificMethodMetadata;

/**
 * You can extends this class to create a specific war class metadata.
 * @param <SC> specific class metadata
 * @param <SM> specific method metadata
 * @param <SF> specific field metadata
 * @author Gael Lalire
 */
public class SpecificWarClassMetadata<
    SC extends ISpecificClassMetadata<SC, SM, SF>,
    SM extends ISpecificMethodMetadata<SC, SM, SF>,
    SF extends ISpecificFieldMetadata<SC, SM, SF>>
        extends SpecificCommonClassMetadata<IWarClassMetadata, IWarMethodMetadata, IWarFieldMetadata, SC, SM, SF>
        implements IWarClassMetadata {

    /**
     * The standard war class metadata.
     */
    private IWarClassMetadata warClassMetadata;

    /**
     * Construct delegation.
     * @param warClassMetadata the standard war class metadata.
     */
    protected SpecificWarClassMetadata(final IWarClassMetadata warClassMetadata) {
        super(warClassMetadata);
        this.warClassMetadata = warClassMetadata;
    }

    /**
     * {@inheritDoc}
     */
    public IWarDeployableMetadata getWarDeployableMetadata() {
        return warClassMetadata.getWarDeployableMetadata();
    }

    /**
     * @return IJwsWebService object representing javax.jws.WebService annotation.
     * @deprecated
     */
    @Deprecated
    public IWebServiceMarker getWebServiceMarker() {
        throw new UnsupportedOperationException("Operation Deprecated !");
    }

    /**
     * Set IJwsWebService object.
     *
     * @param ws object representing javax.jws.WebService annotation.
     * @deprecated
     */
    @Deprecated
    public void setWebServiceMarker(IWebServiceMarker ws) {
        throw new UnsupportedOperationException("Operation Deprecated !");
    }

}
